@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 11004 2018-05-01 01:15:42Z Kevin $
+# $Id: Mailer.py 11540 2019-05-12 11:10:35Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $ (Last)
+# $Author: Andy $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 11004 $
+# $Revision: 11540 $
 
 import os
 import re
@@ -29,6 +29,7 @@ from smtplib import SMTPRecipientsRefused
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
+from django.utils import timezone
 from django.core.mail import EmailMessage, EmailMultiAlternatives
 from django.utils.encoding import smart_str, smart_unicode
 from django.contrib.sites.models import Site
@@ -220,8 +221,10 @@ class CloudMailer(Mailer):
 
         if self.test:
             return True
-
-        if self.newsletter.sending_date <= datetime.now() and \
+            
+        # can't compare offset-naive and offset-aware datatimes
+        now = timezone.now()
+        if self.newsletter.sending_date <= now and \
                (self.newsletter.status == Newsletter.WAITING):
             return True
 
@@ -229,7 +232,7 @@ class CloudMailer(Mailer):
             ('[%d]_[can_send]_CANNOT: Newsletter(status: %d) can not send:'
              'sending_date: %s, datetime.now: %s (TZ: %s).') %
             (self.newsletter.id, self.newsletter.status,
-             self.newsletter.sending_date, datetime.now(),
+             self.newsletter.sending_date, now,
              os.environ.get('TZ', 'None')))
 
         return False
