@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10797 2018-03-01 02:31:02Z David $
+# $Id: StatisticsHandler.py 11006 2018-05-01 07:48:58Z Kevin $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
-# $Revision: 10797 $
+# $Author: Kevin $
+# $Date: 2018-05-01 15:48:58 +0800 (週二, 01 五月 2018) $
+# $Revision: 11006 $
 
 from datetime import timedelta, datetime
 
@@ -858,8 +858,9 @@ def getSubscriberHistory(requestGetData, conditions):
     """
 
     statusCode = conditions.pop('status', None)
+    QList = conditions.pop('QList', [])
 
-    contactStatus = ContactMailingStatus.objects.filter(**conditions)
+    contactStatus = ContactMailingStatus.objects.filter(*QList, **conditions)
     contactStatus = contactStatus.annotate(d=modelsMax("creation_date"),
                                            qid=modelsMax("id"))
     contactStatus = contactStatus.values('contact', 'qid')
